@@ -7,7 +7,8 @@
 #include "gameview.h"
 #include "gamescene.h"
 
-GameView::GameView(Game *p_game) : QGraphicsView(new GameScene(p_game))
+GameView::GameView(Game *p_game)
+    : QGraphicsView(new GameScene(p_game))
 {
     setFrameStyle(QFrame::NoFrame);
     setFocusPolicy(Qt::StrongFocus);
@@ -15,10 +16,7 @@ GameView::GameView(Game *p_game) : QGraphicsView(new GameScene(p_game))
     connect(this, &GameView::keyPressed, p_game, &Game::keyPressEvent);
 }
 
-GameView::~GameView()
-{
-
-}
+GameView::~GameView() = default;
 
 void GameView::resizeEvent(QResizeEvent *)
 {
@@ -37,4 +35,3 @@ void GameView::keyPressEvent(QKeyEvent *p_event)
 {
     Q_EMIT keyPressed(p_event);
 }
-
